#
# spec file for package python-apiron
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2019-2022 Dr. Axel Braun <DocB@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-apiron
Version:        8.0.0.post1
Release:        1.1
Summary:        Apiron helps you cook a tasty client for RESTful APIs
License:        MIT
URL:            https://github.com/ithaka/apiron
Source:         https://files.pythonhosted.org/packages/source/a/apiron/apiron-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 2.11.1}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-requests >= 2.11.1
BuildArch:      noarch
%python_subpackages

%description
Gathering data from multiple services has become a ubiquitous task for web application developers. The complexity can grow quickly: calling an API endpoint with multiple parameter sets, calling multiple API endpoints, calling multiple endpoints in multiple APIs. While the business logic can get hairy, the code to interact with those APIs doesn't have to.

apiron provides declarative, structured configuration of services and endpoints with a unified interface for interacting with them.

%prep
%setup -q -n apiron-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# TestEndpoint.test_call - online test
%pytest -k 'not test_call'

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/apiron
%{python_sitelib}/apiron-%{version}.dist-info

%changelog
* Mon Feb  3 2025 Dirk Müller <dmueller@suse.com>
- update to 8.0.0.post1:
  * Modernize package quality tooling and configuration
  * Add support for Python 3.13
* Thu Oct 10 2024 Dirk Müller <dmueller@suse.com>
- update to 8.0.0:
  * Updated to simpler typing syntax for optional arguments and
    iterable types using `pyupgrade`
  * Reformatted files constrained to Python 3.8+ syntax using
    `black`
  * Updated documentation to prefer `tox` usage
  * Updated documentation dependencies and removed upper bounds
    on their versions
  * Add support for Python 3.12
  * Remove upper bound on dependencies
* Wed Jan 17 2024 Matej Cepl <mcepl@cepl.eu>
- Clean up the SPEC file
* Tue Jan 16 2024 Axel Braun <axel.braun@gmx.de>
- enable %%{?sle15_python_module_pythons}
* Sun Jul 16 2023 Dirk Müller <dmueller@suse.com>
- update to 7.1.0-post.3:
  * Update permissions in publishing workflow to allow publishing
    of files to GitHub releases
  * Use `package` and `wheel_build_env` to speed up tests as this
    is a pure Python package. See the tox docs for more detail.
  * Use PyPI trusted publishing instead of manual token
    authentication
  * You can now configure `retry_spec` and `timeout_spec` at the
    endpoint level. Calls to endpoints may override the endpoint-
    level configuration when necessary.
* Mon Dec 19 2022 Axel Braun <axel.braun@gmx.de>
- version 7.0.0
  * Fixed: Ensure py.typed files end up in binary wheel distribution, which may break type checking for consumers
  * Added:
    Run tests against Python 3.11
    Stop ignoring imports during type checking
* Sun Jan  2 2022 Axel Braun <axel.braun@gmx.de>
- version 6.1.0
  * Add py.typed file so mypy can check against package types in downstream applications
  * Use interpolation for logging messages to avoid wasted computation
* Sun Aug 29 2021 Axel Braun <axel.braun@gmx.de>
- version 6.0.0.post1
  * Move from Travis CI to GitHub Actions for testing and publishing
    Use PEP 517 builds
  * Testing matrix and trove classifiers for Python 3.9
    Type hints for all classes, methods, and functions
  * Support for Python 3.6 has been removed due to its impending end of life and
    the desire to leverage features from 3.7
  * Remove Python 3.10 testing and support for now, as Travis CI only has
    Python 3.10.0a5 which isn't compatible with recent pytest-randomly releases
  * Indicate (by renaming) that all functions in the client module are private, except for call
* Mon Aug 31 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 5.1.0:
  * Ability to specify proxies for a Service definition so all calls to the
    service use the defined proxies
  * Ability to specify auth for a Service definition so all calls to the
    service use the defined authentication
  * Ability to specify return_raw_response_object at the endpoint level,
    overridden by any value specified at call time
* Tue Dec  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Drop needless service, one can call the command directly:
  osc service localrun download_files
- Fix the test call to really execute the tests
- Run the spec-cleaner
* Mon Dec  2 2019 Axel Braun <axel.braun@gmx.de>
- version 5.0.0
  tests added
* Mon Aug 26 2019 Axel Braun <axel.braun@gmx.de>
- version 4.1.0
  initial build on OBS
